package de.dser.pr.presentations.easymock;

public class SleepingConditionChecker {
    private static final int CHECK_INTERVAL_IN_MS = 50;
    private static final int TIMEOUT_IN_MS = 1000;

    public void sleepUntilConditionMet(Condition condition) throws TimeOutReachedException {
        long timeoutTimeStamp = buildTimeOutTimeStamp(TIMEOUT_IN_MS);

        boolean conditionMet = condition.isConditionMet();
        while (!timeOutReached(timeoutTimeStamp) && !conditionMet) {
            sleep(CHECK_INTERVAL_IN_MS);
            conditionMet = condition.isConditionMet();
        }

        if (!conditionMet)
            throw new TimeOutReachedException(CHECK_INTERVAL_IN_MS);
    }

    private void sleep(long sleepTime) throws TimeOutReachedException {
        try {
            Thread.sleep(sleepTime);
        } catch (InterruptedException e) {
            throw new TimeOutReachedException(e);
        }
    }

    private long buildTimeOutTimeStamp(int timeOutInMs) {
        return System.currentTimeMillis() + timeOutInMs;
    }

    private boolean timeOutReached(long timeOutTimeStamp) {
        return System.currentTimeMillis() > timeOutTimeStamp;
    }
}
