package de.dser.pr.presentations.easymock;

import org.easymock.EasyMock;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class SleepingConditionCheckerTest {
    private SleepingConditionChecker sleepingConditionChecker;

    @Before
    public void setUp() throws Exception {
        sleepingConditionChecker = new SleepingConditionChecker();
    }

    @Test(timeout = 1500)
    public void testSleepUntilConditionMetUsingInterfaceImplementation() throws Exception {
		 MockCondition mockCondition = new MockCondition(5);

		 double startTime = System.currentTimeMillis();
		 sleepingConditionChecker.sleepUntilConditionMet(mockCondition);
		 double duration = System.currentTimeMillis() - startTime;

		 assertEquals(250, duration, 40);
	 }

    @Test(timeout = 1500)
    public void testSleepUntilConditionMetUsingAnonymousClass() throws Exception {
		 double startTime = System.currentTimeMillis();
		 sleepingConditionChecker.sleepUntilConditionMet(new Condition() {
			 private int countOfCalls = 5;
			 public boolean isConditionMet() {
				 return --countOfCalls == 0;
			 }
		 });
		 double duration = System.currentTimeMillis() - startTime;

		 assertEquals(250, duration, 40);
    }

    @Test(timeout = 1500)
    public void testSleepUntilConditionMetUsingEasyMock() throws Exception {
		 Condition condition = EasyMock.createMock(Condition.class);
		 EasyMock.expect(condition.isConditionMet()).andReturn(false).times(4).andReturn(true).times(1);

		 EasyMock.replay(condition);
		 double startTime = System.currentTimeMillis();
		 sleepingConditionChecker.sleepUntilConditionMet(condition);
		 double duration = System.currentTimeMillis() - startTime;
		 EasyMock.verify(condition);

		 assertEquals(250, duration, 40);
	 }
}
