package de.dser.pr.presentations.easymock.recipes;

import org.easymock.Capture;
import org.easymock.EasyMock;
import org.junit.Before;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class CustomerServiceTest {
	@Before
	public void setUp() throws Exception {
	}

	@Test
	public void testGenerateNewCustomerCauseWeNeedMoney() throws Exception {
		CustomerDAO customerDAO = EasyMock.createMock(CustomerDAO.class);
		CustomerService customerService = new CustomerService(customerDAO);

		customerDAO.create(
				  EasyMock.matches("Kevin|Peter|Angela|William"),
				  EasyMock.contains("i"),
				  EasyMock.matches("\\d{8}"));

		EasyMock.replay(customerDAO);
		customerService.generateNewCustomerCauseWeNeedMoney();
		EasyMock.verify(customerDAO);
	}

	@Test
	public void testChangePasswordChangesPasswordIfPasswordValid() throws Exception {
		CustomerDAO customerDAO = EasyMock.createMock(CustomerDAO.class);
		CustomerService customerService = new CustomerService(customerDAO);

		EasyMock.expect(customerDAO.read(1L)).andReturn(new Customer(1L, "Kevin", "Mitnick", "s3cr3t"));
		Capture<Customer> customerCapture = new Capture<Customer>();
		customerDAO.update(EasyMock.capture(customerCapture));

		EasyMock.replay(customerDAO);
		customerService.changePassword(1L, "s3cr3t", "31337");
		EasyMock.verify(customerDAO);

		Customer customer = customerCapture.getValue();
		assertEquals(new Long(1), customer.getId());
		assertEquals("Kevin", customer.getFirstName());
		assertEquals("Mitnick", customer.getLastName());
		assertEquals("31337", customer.getPassword());

	}

}
